@@ -10,10 +10,7 @@ def get_load_single_xblock():
     Returns:
         [Function]: load_single_xblock function.
     """
-    try:
-        from courseware.module_render import load_single_xblock  # pylint: disable=import-outside-toplevel
-    except ImportError:
-        load_single_xblock = object
+    from courseware.module_render import load_single_xblock  # pylint: disable=C0415, E0401
     return load_single_xblock
 
 
@@ -25,7 +22,7 @@ def get_item_not_found_exception():
         [Class]: ItemNotFoundError exception.
     """
     try:
-        from xmodule.modulestore.exceptions import ItemNotFoundError  # pylint: disable=import-outside-toplevel
+        from xmodule.modulestore.exceptions import ItemNotFoundError  # pylint: disable=C0415, E0401
     except ImportError:
         ItemNotFoundError = Exception
     return ItemNotFoundError
